@@ -4,7 +4,7 @@
  * This file is part of msmtp, an SMTP client.
  *
  * Copyright (C) 2000, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010, 2011,
- * 2014, 2016, 2018, 2019
+ * 2014, 2016, 2018, 2019, 2020
  * Martin Lambers <marlam@marlam.de>
  *
  *   This program is free software; you can redistribute it and/or modify
@@ -128,13 +128,16 @@ smtp_server_t smtp_new(FILE *debug, int protocol)
  * see smtp.h
  */
 
-int smtp_connect(smtp_server_t *srv, const char *proxy_host, int proxy_port,
+int smtp_connect(smtp_server_t *srv,
+        const char *socketname,
+        const char *proxy_host, int proxy_port,
         const char *host, int port, const char *source_ip, int timeout,
         char **server_canonical_name, char **server_address,
         char **errstr)
 {
-    return net_open_socket(proxy_host, proxy_port, host, port, source_ip,
-            timeout, &srv->fd, server_canonical_name, server_address, errstr);
+    return net_open_socket(socketname, proxy_host, proxy_port, host, port,
+            source_ip, timeout, &srv->fd,
+            server_canonical_name, server_address, errstr);
 }
 
 
@@ -1676,7 +1679,8 @@ int smtp_send_envelope(smtp_server_t *srv,
  * see smtp.h
  */
 
-int smtp_send_mail(smtp_server_t *srv, FILE *mailf, int keep_bcc,
+int smtp_send_mail(smtp_server_t *srv, FILE *mailf,
+        int keep_from, int keep_bcc,
         long *mailsize, char **errstr)
 {
     char bigbuffer[MAIL_BUFSIZE + 3];   /* buffer + leading dot + ending CRLF */
@@ -1685,6 +1689,7 @@ int smtp_send_mail(smtp_server_t *srv, FILE *mailf, int keep_bcc,
     char *send_buf;
     size_t send_len;
     int in_header;
+    int in_from;
     int in_bcc;
     int line_starts;
     int line_continues;
@@ -1693,6 +1698,7 @@ int smtp_send_mail(smtp_server_t *srv, FILE *mailf, int keep_bcc,
     bigbuffer[0] = '.';
     buffer = bigbuffer + 1;
     in_header = 1;
+    in_from = 0;
     in_bcc = 0;
     line_continues = 0;
     e = SMTP_EOK;
@@ -1737,44 +1743,61 @@ int smtp_send_mail(smtp_server_t *srv, FILE *mailf, int keep_bcc,
              * character */
             line_continues = 0;
         }
-        if (!keep_bcc)
+        if (line_starts && in_header && buffer[0] == '\0')
         {
-            if (line_starts && in_header && buffer[0] == '\0')
+            in_header = 0;
+        }
+        if (in_header)
+        {
+            if (line_starts)
             {
-                in_header = 0;
-            }
-            if (in_header)
-            {
-                if (line_starts)
+                if (!keep_from && strncasecmp(buffer, "From:", 5) == 0)
                 {
-                    if (strncasecmp(buffer, "Bcc:", 4) == 0)
+                    in_from = 1;
+                    /* remove From header by ignoring this line */
+                    continue;
+                }
+                else if (!keep_from && in_from)
+                {
+                    /* continued header lines begin with "horizontal
+                     * whitespace" (RFC 2822, section 2.2.3) */
+                    if (buffer[0] == '\t' || buffer[0] == ' ')
                     {
-                        in_bcc = 1;
                         /* remove Bcc header by ignoring this line */
                         continue;
                     }
-                    else if (in_bcc)
+                    else
                     {
-                        /* continued header lines begin with "horizontal
-                         * whitespace" (RFC 2822, section 2.2.3) */
-                        if (buffer[0] == '\t' || buffer[0] == ' ')
-                        {
-                            /* remove Bcc header by ignoring this line */
-                            continue;
-                        }
-                        else
-                        {
-                            in_bcc = 0;
-                        }
+                        in_from = 0;
                     }
                 }
-                else
+                else if (!keep_bcc && strncasecmp(buffer, "Bcc:", 4) == 0)
                 {
-                    if (in_bcc)
+                    in_bcc = 1;
+                    /* remove Bcc header by ignoring this line */
+                    continue;
+                }
+                else if (!keep_bcc && in_bcc)
+                {
+                    /* continued header lines begin with "horizontal
+                     * whitespace" (RFC 2822, section 2.2.3) */
+                    if (buffer[0] == '\t' || buffer[0] == ' ')
                     {
                         /* remove Bcc header by ignoring this line */
                         continue;
                     }
+                    else
+                    {
+                        in_bcc = 0;
+                    }
+                }
+            }
+            else
+            {
+                if ((!keep_from && in_from) || (!keep_bcc && in_bcc))
+                {
+                    /* remove From or Bcc header by ignoring this line */
+                    continue;
                 }
             }
         }
